@@ -60,10 +60,11 @@ Architecture: all
         wt.add(["debian", "debian/changelog", "debian/control",
                 "debian/rules", "debian/compat"])
         wt.commit('initial commit')
-        (out, err) = self.run_bzr("debrelease package --skip-upload --builder true", retcode=0)
+        (out, err) = self.run_bzr(
+            "debrelease package --skip-upload --builder true", retcode=0)
         self.assertContainsRe(
             err, 'Building the package in .*/breezy-foo-2.8.17, using true\n')
-        self.assertEquals("", out)
+        self.assertEqual("", out)
         self.assertEqual(2, wt.branch.revno())
         self.assertEqual(
                 'releasing package breezy-foo version 2.8.17',
@@ -82,7 +83,8 @@ Architecture: all
             ])
         wt.add(["debian", "debian/changelog"])
         (out, err) = self.run_bzr("debrelease package", retcode=3)
-        self.assertEquals(
-            'brz: ERROR: Build refused because there are unknown files in the tree. To '
+        self.assertEqual(
+            'brz: ERROR: Build refused because there are unknown '
+            'files in the tree. To '
             "list all known files, run 'bzr unknowns'.\n", err)
-        self.assertEquals("", out)
+        self.assertEqual("", out)
